<!DOCTYPE html>
<html lang="en">

<head>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta1/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-giJF6kkoqNQ00vy+HMDP7azOuL0xtbfIcaT9wjKHr8RbDVddVHyTfAAsrekwKmP1" crossorigin="anonymous">
    <link href="./css/all.min.css" rel="stylesheet">
    <link href="./css/oliver_twist.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta1/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-ygbV9kiqUc6oa4msXn9868pTtWMgiQaeYH7/t7LECLbyPA2x65Kgf80OJFdroafW"
        crossorigin="anonymous"></script>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
</head>

{% import "macros.jinja" as macros %}

<body>
    {% include 'nav_bar.html' %}
    {% if model_name %}
    <div class="container model-page-name">
        <h1>{{ model_name }}</h1>
    </div>
    <hr />
    {% endif %}
    <div class="container">
        <h1>Summary</h1>
        <div class="container">
            {{ macros.summary_list(summary) }}
        </div>
        {% if model_name %}
        <div class="container">
            <table class="table table-striped">
                <thead>
                    <tr>
                        {% for metric in metrics %}
                        <th>{{ metric.pretty_name }}</th>
                        {% endfor %}
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        {% for metric in metrics %}
                        <td>{{ '%0.2f'| format(metric.score|float) }}</td>
                        {% endfor %}
                    </tr>
            </table>
        </div>
        {% endif %}
    </div>
    <hr />
    <div class="container">
        <div class="container">
            {% block content %}{% endblock %}
        </div>
    </div>
</body>

</html>