{% extends "base.html" %}
{% block content %}
<h1>Results</h1>
<table class="table table-striped">
    <thead>
        <tr>
            <th>Name</th>
            <th>Summary</th>
        </tr>
    </thead>
    <tbody>
        {% for model in models %}
        <tr>
            <td>{{ macros.link_to_model_page(model) }}</td>
            <td>
                {{ macros.summary_list(model.summary) }}
            </td>
        </tr>
        {% endfor %}
    </tbody>
</table>
{% endblock %}