<nav class="navbar navbar-dark">
    <div class="container-fluid">
        <a class="navbar-brand" href="index.html"><img src="./images/oliver_twist_logo.svg" alt="" width="50" height="50" class="d-inline-block">Oliver Twist</a>
    </div>
</nav>